==> haskell-success-0.2.6-300-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 success
version:              0.2.6
visibility:           public
id:                   success-0.2.6-7vx5mWXKB8i8B2ZBgBOlNR
key:                  success-0.2.6-7vx5mWXKB8i8B2ZBgBOlNR
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/success 
synopsis:
    A version of Either specialised for encoding of success or failure

description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.

category:             Data, Failure
abi:                  d90f8113304d209fcb32c38c2707b1e1
exposed:              True
exposed-modules:      Success.Impure Success.Pure
import-dirs:          /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-success
hs-libraries:         HSsuccess-0.2.6-7vx5mWXKB8i8B2ZBgBOlNR
depends:
    base-4.17.2.1 monad-control-1.0.3.1-DSKGk7hVXWfFdb7q3Orv7L
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-CLSmRvqNTF5Lcd4OvY3BYQ

haddock-interfaces:   /usr/share/doc/haskell-success/html/success.haddock
haddock-html:         /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-success-0.2.6-301-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-success.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 success
version:              0.2.6
visibility:           public
id:                   success-0.2.6-AQ2aCsbZytx7KZG2ZjS4fz
key:                  success-0.2.6-AQ2aCsbZytx7KZG2ZjS4fz
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/success 
synopsis:
    A version of Either specialised for encoding of success or failure

description:
    The primary motivation for creation of this package was the need
    for the '\''Alternative'\'' instance of '\''Either'\'',
    which there is no sane way to implement.
    The type provided by this library extends '\''Either'\'' in a way to provide the missing instance.

category:             Data, Failure
abi:                  dd7e8d081f3d6f7cc8a1fa587148cb3c
exposed:              True
exposed-modules:      Success.Impure Success.Pure
import-dirs:          /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs:         /usr/lib/ghc-9.4.8/site-local/success-0.2.6
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/success-0.2.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-success
hs-libraries:         HSsuccess-0.2.6-AQ2aCsbZytx7KZG2ZjS4fz
depends:
    base-4.17.2.1 monad-control-1.0.3.1-Eri4AwhrtCa8G52kkUFfeD
    mtl-2.2.2 transformers-0.5.6.2
    transformers-base-0.4.6-9gqoIpeYmGjDLnucKUpqef

haddock-interfaces:   /usr/share/doc/haskell-success/html/success.haddock
haddock-html:         /usr/share/doc/haskell-success/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
